==> syncfusion_flutter_maps-18.2.44-beta.tar.gz: lib/src/features/maps_marker.dart <==
part of maps;

class MapMarker extends SingleChildRenderObjectWidget {
  const MapMarker({
    Key key,
    @required this.longitude,
    @required this.latitude,
    this.size,
    this.iconColor = Colors.blue,
    this.iconStrokeColor,
    this.iconStrokeWidth = 1.0,
    this.iconType = MapIconType.circle,
    this.child,
  })  : assert(longitude != null),
        assert(latitude != null),
        super(key: key, child: child);

  final double longitude;

  final double latitude;

  final Size size;

  final Color iconColor;

  final Color iconStrokeColor;

  final double iconStrokeWidth;

  final MapIconType iconType;

  ///Accepts any type of widget.
  final Widget child;

  @override
  RenderObject createRenderObject(BuildContext context) {
    return _RenderMapMarker(
      longitude: longitude,
      latitude: latitude,
      markerSize: size,
      iconColor: iconColor,
      iconStrokeColor: iconStrokeColor,
      iconStrokeWidth: iconStrokeWidth,
      iconType: iconType,
    );
  }

  @override
  void updateRenderObject(BuildContext context, _RenderMapMarker renderObject) {
    renderObject
      ..longitude = longitude
      ..latitude = latitude
      ..markerSize = size
      ..iconColor = iconColor
      ..iconStrokeColor = iconStrokeColor
      ..iconStrokeWidth = iconStrokeWidth
      ..iconType = iconType;
  }
}

class _RenderMapMarker extends RenderProxyBox {
  _RenderMapMarker({
    double longitude,
    double latitude,
    Size markerSize,
    Color iconColor,
    Color iconStrokeColor,
    double iconStrokeWidth,
    MapIconType iconType,
  })  : _longitude = longitude,
        _latitude = latitude,
        _markerSize = markerSize,
        _iconColor = iconColor,
        _iconStrokeColor = iconStrokeColor,
        _iconStrokeWidth = iconStrokeWidth,
        _iconType = iconType;

  final _MapIconShape _iconShape = const _MapIconShape();

  final Size _defaultMarkerSize = const Size(14.0, 14.0);

  double get longitude => _longitude;
  double _longitude;
  set longitude(double value) {
    if (_longitude == value) {
      return;
    }
    assert(value != null);
    _longitude = value;
    markNeedsPaint();
  }

  double get latitude => _latitude;
  double _latitude;
  set latitude(double value) {
    if (_latitude == value) {
      return;
    }
    assert(value != null);
    _latitude = value;
    markNeedsPaint();
  }

  Size get markerSize => _markerSize;
  Size _markerSize;
  set markerSize(Size value) {
    if (_markerSize == value) {
      return;
    }
    _markerSize = value;
    markNeedsLayout();
  }

  Color get iconColor => _iconColor;
  Color _iconColor;
  set iconColor(Color value) {
    if (_iconColor == value) {
      return;
    }
    _iconColor = value;
    if (child == null) {
      markNeedsPaint();
    }
  }

  Color get iconStrokeColor => _iconStrokeColor;
  Color _iconStrokeColor;
  set iconStrokeColor(Color value) {
    if (_iconStrokeColor == value) {
      return;
    }
    _iconStrokeColor = value;
    if (child == null) {
      markNeedsPaint();
    }
  }

  double get iconStrokeWidth => _iconStrokeWidth;
  double _iconStrokeWidth;
  set iconStrokeWidth(double value) {
    if (_iconStrokeWidth == value) {
      return;
    }
    assert(value != null);
    _iconStrokeWidth = value;
    if (child == null) {
      markNeedsPaint();
    }
  }

  MapIconType get iconType => _iconType;
  MapIconType _iconType;
  set iconType(MapIconType value) {
    if (_iconType == value) {
      return;
    }
    assert(value != null);
    _iconType = value;
    if (child == null) {
      markNeedsPaint();
    }
  }

  @override
  bool get isRepaintBoundary => true;

  @override
  void performLayout() {
    if (_markerSize != null) {
      child?.layout(BoxConstraints.tight(_markerSize));
      size = _markerSize;
    } else {
      if (child != null) {
        child.layout(constraints.loosen(), parentUsesSize: true);
        size = child.size;
      } else {
        size = _defaultMarkerSize;
      }
    }
  }

  @override
  void paint(PaintingContext context, Offset offset) {
    if (child == null) {
      _iconShape.paint(context, offset,
          parentBox: this,
          mapThemeData: null,
          iconSize: size,
          color: _iconColor,
          strokeColor: _iconStrokeColor,
          strokeWidth: _iconStrokeWidth,
          iconType: _iconType);
    } else {
      super.paint(context, offset);
    }
  }
}

==> syncfusion_flutter_maps-18.2.45-beta.tar.gz: lib/src/features/maps_marker.dart <==
part of maps;

class MapMarker extends SingleChildRenderObjectWidget {
  const MapMarker({
    Key key,
    @required this.longitude,
    @required this.latitude,
    this.size,
    this.iconColor,
    this.iconStrokeColor,
    this.iconStrokeWidth,
    this.iconType = MapIconType.circle,
    this.child,
  })  : assert(longitude != null),
        assert(latitude != null),
        super(key: key, child: child);

  final double longitude;

  final double latitude;

  final Size size;

  final Color iconColor;

  final Color iconStrokeColor;

  final double iconStrokeWidth;

  final MapIconType iconType;

  /// Accepts any type of widget.
  final Widget child;

  @override
  RenderObject createRenderObject(BuildContext context) {
    return _RenderMapMarker(
      longitude: longitude,
      latitude: latitude,
      markerSize: size,
      iconColor: iconColor,
      iconStrokeColor: iconStrokeColor,
      iconStrokeWidth: iconStrokeWidth,
      iconType: iconType,
      mapsThemeData: SfMapsTheme.of(context),
    );
  }

  @override
  void updateRenderObject(BuildContext context, _RenderMapMarker renderObject) {
    renderObject
      ..longitude = longitude
      ..latitude = latitude
      ..markerSize = size
      ..iconColor = iconColor
      ..iconStrokeColor = iconStrokeColor
      ..iconStrokeWidth = iconStrokeWidth
      ..iconType = iconType
      ..mapsThemeData = SfMapsTheme.of(context);
  }
}

class _RenderMapMarker extends RenderProxyBox {
  _RenderMapMarker({
    double longitude,
    double latitude,
    Size markerSize,
    Color iconColor,
    Color iconStrokeColor,
    double iconStrokeWidth,
    MapIconType iconType,
    SfMapsThemeData mapsThemeData,
  })  : _longitude = longitude,
        _latitude = latitude,
        _markerSize = markerSize,
        _iconColor = iconColor,
        _iconStrokeColor = iconStrokeColor,
        _iconStrokeWidth = iconStrokeWidth,
        _mapsThemeData = mapsThemeData,
        _iconType = iconType;

  final _MapIconShape _iconShape = const _MapIconShape();

  final Size _defaultMarkerSize = const Size(14.0, 14.0);

  double get longitude => _longitude;
  double _longitude;
  set longitude(double value) {
    if (_longitude == value) {
      return;
    }
    assert(value != null);
    _longitude = value;
    markNeedsPaint();
  }

  double get latitude => _latitude;
  double _latitude;
  set latitude(double value) {
    if (_latitude == value) {
      return;
    }
    assert(value != null);
    _latitude = value;
    markNeedsPaint();
  }

  Size get markerSize => _markerSize;
  Size _markerSize;
  set markerSize(Size value) {
    if (_markerSize == value) {
      return;
    }
    _markerSize = value;
    markNeedsLayout();
  }

  Color get iconColor => _iconColor;
  Color _iconColor;
  set iconColor(Color value) {
    if (_iconColor == value) {
      return;
    }
    _iconColor = value;
    if (child == null) {
      markNeedsPaint();
    }
  }

  Color get iconStrokeColor => _iconStrokeColor;
  Color _iconStrokeColor;
  set iconStrokeColor(Color value) {
    if (_iconStrokeColor == value) {
      return;
    }
    _iconStrokeColor = value;
    if (child == null) {
      markNeedsPaint();
    }
  }

  double get iconStrokeWidth => _iconStrokeWidth;
  double _iconStrokeWidth;
  set iconStrokeWidth(double value) {
    if (_iconStrokeWidth == value) {
      return;
    }
    assert(value != null);
    _iconStrokeWidth = value;
    if (child == null) {
      markNeedsPaint();
    }
  }

  MapIconType get iconType => _iconType;
  MapIconType _iconType;
  set iconType(MapIconType value) {
    if (_iconType == value) {
      return;
    }
    assert(value != null);
    _iconType = value;
    if (child == null) {
      markNeedsPaint();
    }
  }

  SfMapsThemeData get mapsThemeData => _mapsThemeData;
  SfMapsThemeData _mapsThemeData;
  set mapsThemeData(SfMapsThemeData value) {
    if (_mapsThemeData == value) {
      return;
    }
    _mapsThemeData = value;
    if (child == null) {
      markNeedsPaint();
    }
  }

  @override
  bool get isRepaintBoundary => true;

  @override
  void performLayout() {
    if (_markerSize != null) {
      child?.layout(BoxConstraints.tight(_markerSize));
      size = _markerSize;
    } else {
      if (child != null) {
        child.layout(constraints.loosen(), parentUsesSize: true);
        size = child.size;
      } else {
        size = _defaultMarkerSize;
      }
    }
  }

  @override
  void paint(PaintingContext context, Offset offset) {
    if (child == null) {
      _iconShape.paint(context, offset,
          parentBox: this,
          mapThemeData: _mapsThemeData,
          iconSize: size,
          color: _iconColor ?? _mapsThemeData.markerIconColor,
          strokeColor: _iconStrokeColor ?? _mapsThemeData.markerIconStrokeColor,
          strokeWidth: _iconStrokeWidth ?? _mapsThemeData.markerIconStrokeWidth,
          iconType: _iconType);
    } else {
      super.paint(context, offset);
    }
  }
}
